"""multistage std cms imaging scripts

Revision ID: 09dec567edcd
Revises: ec5653e2ec49
Create Date: 2021-10-11 09:06:08.863906

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "09dec567edcd"
down_revision = "ec5653e2ec49"
branch_labels = None
depends_on = None


envoy_content = """#!/bin/sh
set -o errexit

export HOME=$TMPDIR
{{#remote}}
export CAPO_PATH=.
export CAPO_PROFILE={{profile}}
{{/remote}}

./framework.sh -d .
chmod 770 .
mv {{sdmId}}.ms ./rawdata
./casa_envoy --standard-img $1 $2

"""

convey_content = """#!/bin/sh
set -o errexit

export HOME=$TMPDIR

./conveyor --deliver-img $1

"""

old_content = """#!/bin/sh

export HOME=$TMPDIR

set -o errexit
./framework.sh -d .
chmod 770 .
mv {{sdmId}}.ms ./rawdata
./casa_envoy --standard-img $1 $2
./conveyor --deliver-img $1

"""


def upgrade():
    op.execute(
        """
        DELETE FROM workflow_templates WHERE filename='std_cms_imaging.sh'
        """
    )
    op.execute(
        f"""
                INSERT INTO workflow_templates (filename, content, workflow_name)
                VALUES ('std_cms_imaging_envoy.sh', E'{envoy_content}', 'std_cms_imaging')
                """
    )
    op.execute(
        f"""
                INSERT INTO workflow_templates (filename, content, workflow_name)
                VALUES ('std_cms_imaging_convey.sh', E'{convey_content}', 'std_cms_imaging')
                """
    )


def downgrade():
    op.execute(
        """
        DELETE FROM workflow_templates
        WHERE filename like ('std_cms_imaging_%.sh')
        AND workflow_name = 'std_cms_imaging'
        """
    )

    op.execute(
        f"""
                INSERT INTO workflow_templates (filename, content, workflow_name)
                VALUES ('std_cms_imaging.sh', E'{old_content}', 'std_cms_imaging')
                """
    )
