#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
""" Unit tests for Capability Service """

# pylint: disable=C0116, C0301, E0401, R0201

from unittest.mock import patch

import pytest

from workspaces.capability.schema import CapabilityExecution
from workspaces.capability.services.capability_info import CapabilityInfo
from workspaces.capability.services.capability_service import CapabilityService


@pytest.mark.usefixtures("mock_capability_service")
class TestCapabilityService:
    """Tests for CapabilityService methods"""

    # FIXME: rewrite this test so it succeeds.
    @pytest.mark.skip("TODO: broken; needs rewrite")
    def test_on_ingestion_complete(
        self,
        mock_capability_service: CapabilityService,
        mock_capability_info: CapabilityInfo,
    ):
        fake_subject = {
            "type": "WorkflowRequest",
            "workflow_request_id": -1,
            "execution_wf_id": "-1",
        }

        fake_ingestion_complete_msg = {
            "subject": fake_subject,
            "service": "workflow",
            "routing_key": "workflow",
            "type": "ingestion-complete",
        }
        save_entity_old_call_count = mock_capability_info.save_entity.call_count
        mock_capability_service.on_ingestion_complete(**fake_ingestion_complete_msg)
        assert mock_capability_info.save_entity.call_count == save_entity_old_call_count + 1
        (request,) = mock_capability_info.save_entity.call_args.args
        assert request.ingested is True

    # FIXME: rewrite this test so it succeeds.
    @pytest.mark.skip("TODO: broken; needs rewrite")
    def test_on_carta_ready(
        self,
        mock_capability_service: CapabilityService,
        mock_capability_info: CapabilityInfo,
        mock_capability_execution: CapabilityExecution,
    ):
        """
        Are we catching the "carta-ready" message and saving the metadata
         to the capability request version?

        :param mock_capability_service: stand-in for capability service
        :param mock_capability_info: stand-in for capability info
        :param mock_capability_execution: stand-in for capability execution
        :return:
        """

        wf_request_id = -2
        carta_url = "decartes_image_carta_url"
        fake_carta_ready_msg = {
            "service": "capability",
            "routing_key": "capability",
            "carta_url": carta_url,
            "subject": {"workflow_request_id": wf_request_id, "argument": {"parent_wf_request_id": -1}},
            "type": "carta-ready",
        }

        save_entity_old_call_count = mock_capability_info.save_entity.call_count

        with patch(
            "workspaces.capability.services.capability_info.CapabilityInfo.lookup_execution_by_workflow_request_id",
            return_value=mock_capability_execution,
        ):
            mock_capability_service.on_carta_ready(**fake_carta_ready_msg)
            assert mock_capability_info.save_entity.call_count == save_entity_old_call_count + 1

            (request_version,) = mock_capability_info.save_entity.call_args.args
            assert request_version.version_number > 0
            assert request_version.workflow_metadata["carta_url"] == carta_url
